# GPTBookMaker

A notebook to create stories using ChatGPT

I used poetry to package management

### Usage

In `main.ipynb`, update the `story_type` and `target_audience` with what you what and run all cells.

### Notes

Is rough at recognizing the previous storyline - will be fixed, thanks!

Need Word installed on computer to work to get PDF. Otherwise this will fail and we will just have docx, no problem!
